0.0.1

* Инициализация проекта

0.0.2

* Включение в MANIFEST.in всех файлов (а не только .py)

0.0.3

* Добавление в вариант форматирования progress3 вывода тега сценария
* Команда формирования html-отчёта на основе junit xml-данных